import json
from oauth2client.service_account import ServiceAccountCredentials
from django.shortcuts import redirect, render
from django.conf import settings
from django.views.decorators.cache import cache_page
from django.http import HttpResponse

def get_access_token(ga_key_filepath):
    # from https://ga-dev-tools.appspot.com/embed-api/server-side-authorization/
    # Defines a method to get an access token from the credentials object.
    # The access token is automatically refreshed if it has expired.

    # The scope for the OAuth2 request.
    SCOPE = 'https://www.googleapis.com/auth/analytics.readonly'

    # Construct a credentials objects from the key data and OAuth2 scope.
    _credentials = ServiceAccountCredentials.from_json_keyfile_name(
        ga_key_filepath, SCOPE)

    return _credentials.get_access_token().access_token

@cache_page(3600)
def token(request):
    # return a cached access token to ajax clients
    access_token = get_access_token(settings.GA_KEY_FILEPATH)
    return HttpResponse(access_token)

def dashboard(request):
    return render(request, 'wagalytics/dashboard.html', {
        'ga_view_id': settings.GA_VIEW_ID,
    })



from django.conf.urls import include, url
from django.core import urlresolvers
from django.conf import settings
from wagtail.wagtailcore import hooks
from wagtail.wagtailadmin.menu import MenuItem
from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse

from . import urls
from . import views


@hooks.register('register_admin_urls')
def register_admin_urls():
    return [
        url(r'^analytics/', include(urls)),
    ]

@hooks.register('register_admin_menu_item')
def register_styleguide_menu_item():
    return MenuItem(
        _('Analytics'),
        urlresolvers.reverse('wagalytics_dashboard'),
        classnames='icon icon-fa-bar-chart',
        order=1000
    )

@hooks.register('insert_editor_js')
def editor_js():
    return """
        <script>
            (function(w,d,s,g,js,fs){
              g=w.gapi||(w.gapi={});g.analytics={q:[],ready:function(f){this.q.push(f);}};
              js=d.createElement(s);fs=d.getElementsByTagName(s)[0];
              js.src='https://apis.google.com/js/platform.js';
              fs.parentNode.insertBefore(js,fs);js.onload=function(){g.load('analytics');};
            }(window,document,'script'));
        </script>
        <script>
            function fetchGAResults(slug) {
                params = {
                    'ids': '%s',
                    'start-date': 'yesterday',
                    'end-date': 'today',
                    'metrics': 'ga:pageviews',
                    'filters': 'ga:pagePath==' + slug
                }
                apiQuery = gapi.client.analytics.data.ga.get(params)
                apiQuery.execute(handleCoreReportingResults);
            }

            function handleCoreReportingResults(results) {
                if (!results.error) {
                    if (results.rows && results.rows.length)
                        showResults(results.rows[0][0]);
                } else {
                    alert('Something broke: ' + results.message);
                }
            }

            function showResults(yesterday_page_views) {
                html_results = '<li class="object"><h2><label>Analytics</label></h2><fieldset>';
                html_results += 'This page has had <strong>' + yesterday_page_views + '</strong>';
                html_results += ' views in the last 24 hours.</fieldset></li>';
                $('#settings ul[class="objects"]').append(html_results);
            }

            gapi.analytics.ready(function() {
                $.get( "%s", function(data) {
                    gapi.analytics.auth.authorize({
                      'serverAuth': {'access_token': data}
                    });
                    // Work out slug from the 'Live' link. TODO: make less fragile
                    slug = $('a[class="status-tag primary"]').attr('href');
                    fetchGAResults(slug);
                });
            })
        </script>
        """ % (settings.GA_VIEW_ID, reverse('wagalytics_token'))



from setuptools import setup, find_packages
from wagalytics import __version__
from codecs import open
from os import path

setup(
    name='wagalytics',
    version=__version__,
    description='Show Google Analytics data in Wagtail.',
    long_description='See https://github.com/tomdyson/wagalytics for details',
    url='https://github.com/tomdyson/wagalytics',
    author='Tom Dyson',
    author_email='tom+wagalytics@torchbox.com',
    license='MIT',
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        'Topic :: Internet :: WWW/HTTP',
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
    keywords='development',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        "wagtail>=0.8.7",
        "Django>=1.7.1",
        "google-api-python-client==1.5.0",
        "oauth2client<3,>=2.0.0",
        "wagtailfontawesome"
    ],
)



from __future__ import absolute_import, unicode_literals
from django.conf.urls import url
from wagalytics.views import dashboard, token

urlpatterns = [
    url(r'^dashboard/$', dashboard, name='wagalytics_dashboard'),
    url(r'^token/$', token, name='wagalytics_token'),
]
